@@ -36,41 +36,6 @@ from pbr import packaging
 from pbr.tests import base
 
 
-class EmailTestCase(base.BaseTestCase):
-
-    def test_str_dict_replace(self):
-        string = 'Johnnie T. Hozer'
-        mapping = {'T.': 'The'}
-        self.assertEqual('Johnnie The Hozer',
-                         packaging.canonicalize_emails(string, mapping))
-
-
-class MailmapTestCase(base.BaseTestCase):
-
-    def setUp(self):
-        super(MailmapTestCase, self).setUp()
-        self.root_dir = self.useFixture(fixtures.TempDir()).path
-        self.mailmap = os.path.join(self.root_dir, '.mailmap')
-
-    def test_mailmap_with_fullname(self):
-        with open(self.mailmap, 'w') as mm_fh:
-            mm_fh.write("Foo Bar <email@foo.com> Foo Bar <email@bar.com>\n")
-        self.assertEqual({'<email@bar.com>': '<email@foo.com>'},
-                         packaging.read_git_mailmap(self.root_dir))
-
-    def test_mailmap_with_firstname(self):
-        with open(self.mailmap, 'w') as mm_fh:
-            mm_fh.write("Foo <email@foo.com> Foo <email@bar.com>\n")
-        self.assertEqual({'<email@bar.com>': '<email@foo.com>'},
-                         packaging.read_git_mailmap(self.root_dir))
-
-    def test_mailmap_with_noname(self):
-        with open(self.mailmap, 'w') as mm_fh:
-            mm_fh.write("<email@foo.com> <email@bar.com>\n")
-        self.assertEqual({'<email@bar.com>': '<email@foo.com>'},
-                         packaging.read_git_mailmap(self.root_dir))
-
-
 class SkipFileWrites(base.BaseTestCase):
 
     scenarios = [
@@ -134,6 +99,18 @@ class SkipFileWrites(base.BaseTestCase):
             (self.option_value.lower() in packaging.TRUE_VALUES
              or self.env_value is not None))
 
+_changelog_content = """04316fe (review/monty_taylor/27519) Make python
+378261a Add an integration test script.
+3c373ac (HEAD, tag: 2013.2.rc2, tag: 2013.2, milestone-proposed) Merge "Lib
+182feb3 (tag: 0.5.17) Fix pip invocation for old versions of pip.
+fa4f46e (tag: 0.5.16) Remove explicit depend on distribute.
+d1c53dd Use pip instead of easy_install for installation.
+a793ea1 Merge "Skip git-checkout related tests when .git is missing"
+6c27ce7 Skip git-checkout related tests when .git is missing
+04984a5 Refactor hooks file.
+a65e8ee (tag: 0.5.14, tag: 0.5.13) Remove jinja pin.
+"""
+
 
 class GitLogsTest(base.BaseTestCase):
 
@@ -148,27 +125,24 @@ class GitLogsTest(base.BaseTestCase):
             fixtures.EnvironmentVariable('SKIP_WRITE_GIT_CHANGELOG'))
 
     def test_write_git_changelog(self):
-        exist_files = [os.path.join(self.root_dir, f)
-                       for f in (".git", ".mailmap")]
-        self.useFixture(fixtures.MonkeyPatch(
-            "os.path.exists",
-            lambda path: os.path.abspath(path) in exist_files))
         self.useFixture(fixtures.FakePopen(lambda _: {
-            "stdout": BytesIO("Author: Foo Bar "
-                              "<email@bar.com>\n".encode('utf-8'))
+            "stdout": BytesIO(_changelog_content.encode('utf-8'))
         }))
 
-        def _fake_read_git_mailmap(*args):
-            return {"email@bar.com": "email@foo.com"}
-
-        self.useFixture(fixtures.MonkeyPatch("pbr.packaging.read_git_mailmap",
-                                             _fake_read_git_mailmap))
-
         packaging.write_git_changelog(git_dir=self.git_dir,
                                       dest_dir=self.temp_path)
 
         with open(os.path.join(self.temp_path, "ChangeLog"), "r") as ch_fh:
-            self.assertTrue("email@foo.com" in ch_fh.read())
+            changelog_contents = ch_fh.read()
+            self.assertIn("2013.2", changelog_contents)
+            self.assertIn("0.5.17", changelog_contents)
+            self.assertIn("------", changelog_contents)
+            self.assertIn("Refactor hooks file", changelog_contents)
+            self.assertNotIn("Refactor hooks file.", changelog_contents)
+            self.assertNotIn("182feb3", changelog_contents)
+            self.assertNotIn("review/monty_taylor/27519", changelog_contents)
+            self.assertNotIn("0.5.13", changelog_contents)
+            self.assertNotIn('Merge "', changelog_contents)
 
     def test_generate_authors(self):
         author_old = u"Foo Foo <email@foo.com>"
@@ -177,7 +151,8 @@ class GitLogsTest(base.BaseTestCase):
         co_author_by = u"Co-authored-by: " + co_author
 
         git_log_cmd = (
-            "git --git-dir=%s log --format=%%aN <%%aE>" % self.git_dir)
+            "git --git-dir=%s log --format=%%aN <%%aE>"
+            % self.git_dir)
         git_co_log_cmd = ("git --git-dir=%s log" % self.git_dir)
         git_top_level = "git rev-parse --show-toplevel"
         cmd_map = {
@@ -253,6 +228,39 @@ class BuildSphinxTest(base.BaseTestCase):
             os.path.exists(
                 "api/fake_package.fake_module.rst") == self.has_autodoc)
 
+    def test_builders_config(self):
+        if self.has_opt:
+            self.distr.command_options["pbr"] = {
+                "autodoc_index_modules": ('setup.cfg', self.autodoc)}
+
+        build_doc = packaging.LocalBuildDoc(self.distr)
+        build_doc.finalize_options()
+
+        self.assertEqual(2, len(build_doc.builders))
+        self.assertIn('html', build_doc.builders)
+        self.assertIn('man', build_doc.builders)
+
+        build_doc = packaging.LocalBuildDoc(self.distr)
+        build_doc.builders = ''
+        build_doc.finalize_options()
+
+        self.assertEqual('', build_doc.builders)
+
+        build_doc = packaging.LocalBuildDoc(self.distr)
+        build_doc.builders = 'man'
+        build_doc.finalize_options()
+
+        self.assertEqual(1, len(build_doc.builders))
+        self.assertIn('man', build_doc.builders)
+
+        build_doc = packaging.LocalBuildDoc(self.distr)
+        build_doc.builders = 'html,man,doctest'
+        build_doc.finalize_options()
+
+        self.assertIn('html', build_doc.builders)
+        self.assertIn('man', build_doc.builders)
+        self.assertIn('doctest', build_doc.builders)
+
 
 class ParseRequirementsTest(base.BaseTestCase):
 
@@ -296,12 +304,6 @@ class ParseRequirementsTest(base.BaseTestCase):
             fh.write("-f foobar")
         self.assertEqual([], packaging.parse_requirements([self.tmp_file]))
 
-    def test_parse_requirements_removes_argparse(self):
-        with open(self.tmp_file, 'w') as fh:
-            fh.write("argparse")
-        if sys.version_info >= (2, 7):
-            self.assertEqual([], packaging.parse_requirements([self.tmp_file]))
-
     def test_parse_requirements_override_with_env(self):
         with open(self.tmp_file, 'w') as fh:
             fh.write("foo\nbar")
@@ -330,6 +332,22 @@ class ParseRequirementsTest(base.BaseTestCase):
         self.assertEqual(['foobar', 'foobaz'],
                          packaging.parse_requirements([self.tmp_file]))
 
+    def test_parse_requirements_python_version(self):
+        with open("requirements-py%d.txt" % sys.version_info[0],
+                  "w") as fh:
+            fh.write("# this is a comment\nfoobar\n# and another one\nfoobaz")
+        self.assertEqual(['foobar', 'foobaz'],
+                         packaging.parse_requirements())
+
+    def test_parse_requirements_right_python_version(self):
+        with open("requirements-py1.txt", "w") as fh:
+            fh.write("thisisatrap")
+        with open("requirements-py%d.txt" % sys.version_info[0],
+                  "w") as fh:
+            fh.write("# this is a comment\nfoobar\n# and another one\nfoobaz")
+        self.assertEqual(['foobar', 'foobaz'],
+                         packaging.parse_requirements())
+
 
 class ParseDependencyLinksTest(base.BaseTestCase):
 
