@@ -77,6 +77,7 @@ try:
 except ImportError:
     import configparser
 
+from pbr import extra_files
 import pbr.hooks
 
 # A simplified RE for this; just checks that the line ends with version
@@ -149,9 +150,6 @@ BOOL_FIELDS = ("use_2to3", "zip_safe", "include_package_data")
 CSV_FIELDS = ("keywords",)
 
 
-log.set_verbosity(log.INFO)
-
-
 def resolve_name(name):
     """Resolve a name like ``module.object`` to an object and return it.
 
@@ -222,7 +220,7 @@ def cfg_to_args(path='setup.cfg'):
         if setup_hooks:
             setup_hooks = [
                 hook for hook in split_multiline(setup_hooks)
-                if hook != 'pbr.hook.setup_hook']
+                if hook != 'pbr.hooks.setup_hook']
             for hook in setup_hooks:
                 hook_fn = resolve_name(hook)
                 try :
@@ -258,23 +256,9 @@ def cfg_to_args(path='setup.cfg'):
         wrap_commands(kwargs)
 
         # Handle the [files]/extra_files option
-        extra_files = has_get_option(config, 'files', 'extra_files')
-        if extra_files:
-            extra_files = split_multiline(extra_files)
-            # Let's do a sanity check
-            for filename in extra_files:
-                if not os.path.exists(filename):
-                    raise DistutilsFileError(
-                        '%s from the extra_files option in setup.cfg does not '
-                        'exist' % filename)
-            # Unfortunately the only really sensible way to do this is to
-            # monkey-patch the manifest_maker class
-            @monkeypatch_method(manifest_maker)
-            def add_defaults(self, extra_files=extra_files, log=log):
-                log.info('[pbr] running patched manifest_maker command '
-                          'with extra_files support')
-                add_defaults._orig(self)
-                self.filelist.extend(extra_files)
+        files_extra_files = has_get_option(config, 'files', 'extra_files')
+        if files_extra_files:
+            extra_files.set_extra_files(split_multiline(files_extra_files))
 
     finally:
         # Perform cleanup if any paths were added to sys.path
@@ -370,8 +354,8 @@ def setup_cfg_to_setup_kwargs(config):
             elif arg == 'cmdclass':
                 cmdclass = {}
                 dist = Distribution()
-                for cls in in_cfg_value:
-                    cls = resolve_name(cls)
+                for cls_name in in_cfg_value:
+                    cls = resolve_name(cls_name)
                     cmd = cls(dist)
                     cmdclass[cmd.get_command_name()] = cls
                 in_cfg_value = cmdclass
